==> viha-5.15.tar.gz: viha-5.15/verkko.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "verkko";
$file = basename(__FILE__);

include "common.php";
include "verkko-ok.php";

echo "
<html>
<head>
 <title>VIHA - Radioverkot</title>
</head>
" . body_bgcolor() . "
<h1>Radioverkkojen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$verkko = get_txt('verkko');
$selite = get_txt('selite');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

if (($add != '') && saa_tehda("$file:add")) {
  $ret = verkko_add_ok($herja,$verkko);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET verkko = '$verkko',
           selite = '$selite',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
}

if (($save != '') && saa_tehda("$file:save")) {
  $ret = verkko_save_ok($herja,$id,$verkko);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET verkko='$verkko',
           selite='$selite',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
  }
  p_herja($ret,$herja);
} # save

if (($confirm != '') && saa_tehda("verkko.php:confirm")) {
  $ret = verkko_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
  }
  p_herja($ret,$herja);
}

if ($clear != '') {
  $id = "0";
  $verkko = '';
  $selite = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = verkko_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $verkko = $a['verkko'];
  $selite = $a['selite'];
}		  

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Verkko:";
if ($readonly) {
  print "<td>$verkko\n";
} else {
  print "<td><input type=\"text\" name=\"verkko\" size=16 maxlength=16";
  print " value=\"$verkko\">\n";
}

print "<tr><td>Selite:";
if ($readonly) {
  print "<td>$selite\n";
} else {
  print "<td><input type=\"text\" name=\"selite\" size=64 maxlength=64";
  print " value=\"$selite\">\n";
}

print "</table>\n";

if ($change != "") {
  print "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  print "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  print "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  print "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  print "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result = my_mysql_query("SELECT * FROM $table ORDER BY verkko");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Verkko<TH>Selite\n";
  while ($a = mysql_fetch_array($result)) {
    echo "<TR><TD>$a[id]", "<TD>$a[ts]", "<TD>$a[verkko]", "<TD>$a[selite]";
    if (($id == "0") && ($a['id'] != "1")) {
      echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei verkkoja.";
 }

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: verkko.php,v 1.8 2009/03/19 17:32:22 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/verkko.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "verkko";
$file = basename(__FILE__);

include "common.php";
include "verkko-ok.php";

echo "
<html>
<head>
 <title>VIHA - Radioverkot</title>
</head>
" . body_bgcolor() . "
<h1>Radioverkkojen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$verkko = get_txt('verkko');
$selite = get_txt('selite');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

if (($add != '') && saa_tehda("$file:add")) {
  $ret = verkko_add_ok($herja,$verkko);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET verkko = '$verkko',
           selite = '$selite',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
}

if (($save != '') && saa_tehda("$file:save")) {
  $ret = verkko_save_ok($herja,$id,$verkko);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET verkko='$verkko',
           selite='$selite',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
  }
  p_herja($ret,$herja);
} # save

if (($confirm != '') && saa_tehda("verkko.php:confirm")) {
  $ret = verkko_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
  }
  p_herja($ret,$herja);
}

if ($clear != '') {
  $id = "0";
  $verkko = '';
  $selite = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = verkko_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $verkko = $a['verkko'];
  $selite = $a['selite'];
}		  

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Verkko:";
if ($readonly) {
  print "<td>$verkko\n";
} else {
  print "<td><input type=\"text\" name=\"verkko\" size=16 maxlength=16";
  print " value=\"$verkko\">\n";
}

print "<tr><td>Selite:";
if ($readonly) {
  print "<td>$selite\n";
} else {
  print "<td><input type=\"text\" name=\"selite\" size=64 maxlength=64";
  print " value=\"$selite\">\n";
}

print "</table>\n";

if ($change != "") {
  print "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  print "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  print "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  print "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  print "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result = my_mysql_query("SELECT * FROM $table ORDER BY verkko");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Verkko<TH>Selite\n";
  while ($a = mysql_fetch_array($result)) {
    echo tr() . "<TD>$a[id]", "<TD>$a[ts]", "<TD>$a[verkko]", "<TD>$a[selite]";
    if (($id == "0") && ($a['id'] != "1")) {
      echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei verkkoja.";
 }

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: verkko.php,v 1.9 2009/09/29 16:09:15 riku Exp $ -->
